{% load i18n wagtailadmin_tags wagtailcore_tags %}
{% icon name="help" %}

## {% blocktrans trimmed %} Things in Wagtail {{ version }} have changed! {% endblocktrans %}

{% wagtail_feature_release_editor_guide_link as editor_guide_link %} {% blocktrans trimmed %} Don't worry, we've got your back. Check out the Wagtail Editor Guide to get the low down on what's changed and some exciting new features! {% endblocktrans %}